pub struct CloudFormationTarget {
pub deployment_id: Option<String>,
pub last_updated_at: Option<f64>,
pub lifecycle_events: Option<Vec<LifecycleEvent>>,
pub resource_type: Option<String>,
pub status: Option<String>,
pub target_id: Option<String>,
pub target_version_weight: Option<f64>,
}Expand description
Information about the target to be updated by an AWS CloudFormation blue/green deployment. This target type is used for all deployments initiated by a CloudFormation stack update.
Fields
deployment_id: Option<String>The unique ID of an AWS CloudFormation blue/green deployment.
last_updated_at: Option<f64>The date and time when the target application was updated by an AWS CloudFormation blue/green deployment.
lifecycle_events: Option<Vec<LifecycleEvent>>The lifecycle events of the AWS CloudFormation blue/green deployment to this target application.
resource_type: Option<String>The resource type for the AWS CloudFormation blue/green deployment.
status: Option<String>The status of an AWS CloudFormation blue/green deployment's target application.
target_id: Option<String> The unique ID of a deployment target that has a type of CloudFormationTarget.
target_version_weight: Option<f64>The percentage of production traffic that the target version of an AWS CloudFormation blue/green deployment receives.