pub struct DeploymentReadyOption {
pub action_on_timeout: Option<String>,
pub wait_time_in_minutes: Option<i64>,
}Expand description
Information about how traffic is rerouted to instances in a replacement environment in a blue/green deployment.
Fields
action_on_timeout: Option<String>Information about when to reroute traffic from an original environment to a replacement environment in a blue/green deployment.
-
CONTINUEDEPLOYMENT: Register new instances with the load balancer immediately after the new application revision is installed on the instances in the replacement environment.
-
STOPDEPLOYMENT: Do not register new instances with a load balancer unless traffic rerouting is started using ContinueDeployment. If traffic rerouting is not started before the end of the specified wait period, the deployment status is changed to Stopped.
wait_time_in_minutes: Option<i64>The number of minutes to wait before the status of a blue/green deployment is changed to Stopped if rerouting is not started manually. Applies only to the STOP_DEPLOYMENT option for actionOnTimeout.