pub struct TargetGroupPairInfo {
pub prod_traffic_route: Option<TrafficRoute>,
pub target_groups: Option<Vec<TargetGroupInfo>>,
pub test_traffic_route: Option<TrafficRoute>,
}Expand description
Information about two target groups and how traffic is routed during an Amazon ECS deployment. An optional test traffic route can be specified.
Fields
prod_traffic_route: Option<TrafficRoute>The path used by a load balancer to route production traffic when an Amazon ECS deployment is complete.
target_groups: Option<Vec<TargetGroupInfo>>One pair of target groups. One is associated with the original task set. The second is associated with the task set that serves traffic after the deployment is complete.
test_traffic_route: Option<TrafficRoute>An optional path used by a load balancer to route test traffic after an Amazon ECS deployment. Validation can occur while test traffic is served during a deployment.