pub struct ErrorInformation {
pub code: Option<String>,
pub message: Option<String>,
}Expand description
Information about a deployment error.
Fields
code: Option<String>For more information, see Error Codes for AWS CodeDeploy in the AWS CodeDeploy User Guide.
The error code:
-
APPLICATIONMISSING: The application was missing. This error code is most likely raised if the application is deleted after the deployment is created, but before it is started.
-
DEPLOYMENTGROUPMISSING: The deployment group was missing. This error code is most likely raised if the deployment group is deleted after the deployment is created, but before it is started.
-
HEALTHCONSTRAINTS: The deployment failed on too many instances to be successfully deployed within the instance health constraints specified.
-
HEALTHCONSTRAINTSINVALID: The revision cannot be successfully deployed within the instance health constraints specified.
-
IAMROLEMISSING: The service role cannot be accessed.
-
IAMROLEPERMISSIONS: The service role does not have the correct permissions.
-
INTERNALERROR: There was an internal error.
-
NOEC2SUBSCRIPTION: The calling account is not subscribed to Amazon EC2.
-
NOINSTANCES: No instances were specified, or no instances can be found.
-
OVERMAXINSTANCES: The maximum number of instances was exceeded.
-
THROTTLED: The operation was throttled because the calling account exceeded the throttling limits of one or more AWS services.
-
TIMEOUT: The deployment has timed out.
-
REVISION_MISSING: The revision ID was missing. This error code is most likely raised if the revision is deleted after the deployment is created, but before it is started.
message: Option<String>An accompanying error message.